@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.7.2.3 2001/12/26 20:47:02 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.7.2.4 2002/08/21 19:24:56 shadow Exp $");
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -34,7 +34,7 @@ RCSID("$Header: /cvs/openafs/src/bozo/bnode.c,v 1.7.2.3 2001/12/26 20:47:02 shad
 #include <afs/fileutil.h>
 #include "bnode.h"
 
-#ifdef AFS_AIX_ENV
+#if defined(AFS_AIX_ENV) || defined(AFS_SUN4_ENV)
 /* All known versions of AIX lack WCOREDUMP but this works */
 #define WCOREDUMP(x) ((x) & 0x80)
 #endif
