@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/usd/usd_file.c,v 1.7.2.1 2001/09/19 22:25:32 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/usd/usd_file.c,v 1.7.2.3 2002/08/21 19:25:03 shadow Exp $");
 
 #include <errno.h>
 #include <fcntl.h>
@@ -24,11 +24,11 @@ RCSID("$Header: /cvs/openafs/src/usd/usd_file.c,v 1.7.2.1 2001/09/19 22:25:32 sh
 #ifdef AFS_DARWIN_ENV
 #include <sys/ioccom.h>
 #endif
-#include <sys/mtio.h>
-#endif /* AFS_AIX_ENV */
-#if defined(AFS_DUX40_ENV) || defined(AFS_OBSD_ENV)
+#if defined(AFS_DUX40_ENV) || defined(AFS_OBSD_ENV) || defined(AFS_SUN4_ENV)
 #include <sys/ioctl.h>
 #endif
+#include <sys/mtio.h>
+#endif /* AFS_AIX_ENV */
 #include <afs/debug.h>
 #include "usd.h"
 
