@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/uss/uss_kauth.c,v 1.4 2001/07/12 19:59:23 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/uss/uss_kauth.c,v 1.5.2.1 2003/01/11 07:42:38 shadow Exp $");
 
 #include "uss_kauth.h"		/*Module interface*/
 #include "uss_common.h"		/*Common defs & operations*/
@@ -28,9 +28,7 @@ RCSID("$Header: /cvs/openafs/src/uss/uss_kauth.c,v 1.4 2001/07/12 19:59:23 shado
 #include <afs/kautils.h>	/*MAXKTCREALMLEN*/
 #include <afs/kaport.h>         /* pack_long */
 
-extern int errno;
 extern afs_int32 KAM_CreateUser();
-extern char *index();
 
 #define uss_kauth_MAX_SIZE	2048
 
@@ -150,7 +148,7 @@ static char *getpipepass() {
     static char gpbuf[BUFSIZ];
     /* read a password from stdin, stop on \n or eof */
     register int i, tc;
-    bzero(gpbuf, sizeof(gpbuf));
+    memset(gpbuf, 0, sizeof(gpbuf));
     for(i=0; i<(sizeof(gpbuf)-1); i++) {
 	tc = fgetc(stdin);
 	if (tc == '\n' || tc == EOF) break;
@@ -555,7 +553,7 @@ afs_int32 uss_kauth_CheckUserName()
 		uss_whoami, UserCell);
 	return(-1);
     }
-    if (index(UserPrincipal, ':') != NULL) {
+    if (strchr(UserPrincipal, ':') != NULL) {
 	fprintf(stderr, "%s: User name '%s' can't have a colon\n",
 		uss_whoami, UserPrincipal);
 	return(-1);
